import {log, reportError} from '../../core/utils';
import {Branch} from '../../models';

let pages: {[key: string]: string[]} = {};

async function updatePagesRegistry(): Promise<void> {
    const branches = await Branch.query().where({interwiki: true});

    pages = {};
    branches.forEach((branch: Branch) => {
        const wiki = branch.name;
        branch.pagesList.forEach((pageName: string) => {
            if (pages[pageName]) {
                pages[pageName].push(wiki);
            } else {
                pages[pageName] = [wiki];
            }
        });
    });

    setTimeout(() => {
        initPagedRegistryUpdate();
    }, 1000 * 60 * 30); // 30 min
}

function initPagedRegistryUpdate(): void {
    updatePagesRegistry().then(() => {
        log('InterWiki page registry updated');
    }).catch(error => {
        reportError(error, {message: 'Error occured during pages list registry update'});
    });
}

initPagedRegistryUpdate();

export default function getWikiListByPageName(name: string): string[] {
    return pages[name] || [];
}
