'use strict';

const {knex, Model} = require('.');

export default class WikidotUser extends Model {
    public uid: number;
    public username: string;
    public regDate: Date;
    public about: string;
    public memberships: {[key: string]: Date | undefined};

    public static get tableName(): string {
        return 'wikidot_users';
    }

    public static upsert(user: Partial<WikidotUser>): Promise<void> {
        const insert = knex(WikidotUser.tableName).insert(user);
        const update = knex.queryBuilder().update(user);
        return knex.raw('? ON CONFLICT (uid) DO ? returning *', [insert, update]).get('rows').get(0);
    }

    public static membersWithDiscordTag(): string[] {
        return knex.raw(`
            SELECT SUBSTRING(about FROM 'Discord<(.*)>') as discord_id
            FROM wikidot_users
            WHERE memberships \\? 'scp-ru' AND about LIKE '%Discord<%>%'
        `).then((result: {rows: Array<{discord_id: string}>}) => {
            return result.rows.map(row => row['discord_id']);
        });
    }
}
