'use strict';

const schedule = require('node-schedule');
const {enqueue, log, logToDiscord} = require('./core/utils');

export default function runScheduler(): void {
    if (process.env.DISABLE_SCHEDULER) {
        log('Scheduler is disabled');
        return;
    }
    log('Scheduler inited');

    schedule.scheduleJob('00 01 * * *', async () => {
        logToDiscord('Scheduling members import');
        await enqueue('members-import-init', ['scp-ru'], 'common');
    });

    schedule.scheduleJob('00 02 * * *', async () => {
        logToDiscord('Scheduling discord member roles sync');
        await enqueue('discord-roles-sync', [], 'common');
    });

    schedule.scheduleJob('00 * * * *', async () => {
        await enqueue('pages-lists-import', [], 'import');
    });

    schedule.scheduleJob('00 00 * * *', async () => {
        logToDiscord('Scheduling featured daily rotation');
        await enqueue('featured-daily-rotation', [], 'critical');
    });

    schedule.scheduleJob('02 00 * * 1', async () => {
        logToDiscord('Scheduling featured weekly rotation');
        await enqueue('featured-weekly-rotation', [], 'critical');
    });

    schedule.scheduleJob('00 10 * * *', async () => {
        logToDiscord('Scheduling scp-ru wiki import');
        await enqueue('wiki-import-init', ['scp-ru'], 'import');
    });

    schedule.scheduleJob('05 20 */7 * *', async () => {
        logToDiscord('Scheduling object titles extraction');
        await enqueue('object-titles-extraction', [], 'import');
    });
}
