"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../../../core/utils");
const models_1 = require("../../../models");
exports.default = async (req, res) => {
    if (!req.user.roles.intBanRecordsWriter) {
        res.status(403).send({ status: 'Unauthorized' });
        return;
    }
    const payload = req.body;
    utils_1.log('Creating int ban record', { payload, user: req.user });
    try {
        const record = await models_1.BanRecord
            .query()
            .insert(utils_1.clearNulls({
            addedBy: req.user.id,
            accusedDiscordId: payload.accusedDiscordId,
            accusedDiscordUsername: payload.accusedDiscordUsername || null,
            caseOrigin: payload.caseOrigin,
            caseModerator: payload.caseModerator || null,
            caseDescription: payload.caseDescription || null,
            bannedUntil: payload.bannedUntil || null
        }))
            .returning('*');
        res.send({
            status: 'ok',
            record
        });
    }
    catch (error) {
        if (error instanceof models_1.ValidationError) {
            res.status(400).send({
                error: 'Validation failed',
                details: error.data
            });
        }
        else {
            res.status(500).send({ error: 'Internal server error' });
        }
        utils_1.reportError(error, {
            message: 'Error creating a record'
        });
    }
};
//# sourceMappingURL=create.js.map