'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../core/utils");
const trello_1 = require("../components/trello");
const wikidot_page_1 = require("../models/wikidot-page");
const wikidot_kit_1 = require("../components/wikidot-kit");
const PAGE_NAME_REG = /^[a-zA-Z0-9_:-]+$/;
const FEATURED_BLOCK_REGEXP = /\[!--\sFEATURED_WEEKLY_START\s--][\s\S]*\[!--\sFEATURED_WEEKLY_END\s--]/;
const WIKI_NAME = 'scp-ru';
const PAGE_NAME = '_default:main';
module.exports = async function run() {
    const previousCards = (await trello_1.getListCards(trello_1.WEEKLY_PREVIOUS_LIST_ID));
    const backlogCards = await trello_1.getListCards(trello_1.WEEKLY_BACKLOG_LIST_ID);
    const current = backlogCards[0];
    if (!current) {
        throw new Error('Featured Weekly Queue is empty');
    }
    const name = current.name;
    if (!PAGE_NAME_REG.test(name)) {
        throw new Error(`Featured Weekly page name is not valid ("${name}")`);
    }
    const annotation = current.desc;
    utils_1.log(`Rotating to page ${name}`);
    const currentPage = await wikidot_page_1.default.query().where({ wikiName: WIKI_NAME, name }).first();
    const updatedBlock = `
[!-- FEATURED_WEEKLY_START --]
[[div class="scp-featured__block"]]
  [[div class="scp-featured__title"]]
    Объект недели
  [[/div]]
  [[div class="scp-featured__page-title"]]
    [/${currentPage.name} ${currentPage.title}]
  [[/div]]
  [[div class="scp-featured__content"]]
    //${annotation}//
  [[/div]]
[[/div]]
[!-- FEATURED_WEEKLY_END --]
    `.trim();
    const content = (await wikidot_kit_1.wk.call(WIKI_NAME, 'pages.get_one', { page: PAGE_NAME })).content;
    const updatedContent = content.replace(FEATURED_BLOCK_REGEXP, updatedBlock);
    await wikidot_kit_1.wk.call(WIKI_NAME, 'pages.save_one', {
        page: PAGE_NAME,
        content: updatedContent
    });
    await trello_1.updateCardList(current.id, trello_1.WEEKLY_PREVIOUS_LIST_ID, (previousCards[0] && previousCards[0].pos - 1));
    utils_1.logToDiscord(`Successfully rotated featured weekly page to ${name}`);
};
//# sourceMappingURL=featured-weekly-rotation.js.map